<?php

defined( 'ABSPATH' ) || die;

class InfilityGlobalErrorRecord {
    public static function init() {
        $method = $_SERVER['REQUEST_METHOD'];
        $request_uri = $_SERVER['REQUEST_URI'];
        $uri = parse_url( $request_uri, PHP_URL_PATH );

        if ( $method === 'GET' ) {
            self::output_js_code();
            if ( $uri === '/cf7_records' ) {
                add_action( 'wp', [ self::class, 'show_cf7_records' ] );
                // self::show_cf7_records();
            }
        } else if ( $method === 'POST' ) {
            if ( $uri === '/cf7_record' ) {
                self::save_cf7_record();
            } else if ( $uri === '/js_error' ) {
                self::save_js_error();
            }
        }

    }

    public static function output_js_code() {
        if ( ! is_admin() ) {
            add_action( 'wp_head', function () {
                ?><script>
                    // cf7 log
                    (function () {
                        var init = false
                        var initFn = function () {
                            if (!window.jQuery) return
                            if (init) {
                                return
                            }
                            init = true
                            var $ = window.jQuery
                            $('form.wpcf7-form').each(function (index, element) {
                                $(element).on('click', '.wpcf7-submit', function () {
                                    var data = $(element).serialize();
                                    $.ajax({
                                        type: 'POST',
                                        url: '/cf7_record',
                                        data: data,
                                    })
                                })
                            })
                        }

                        if (window.jQuery) {
                            window.jQuery(document).ready(initFn)
                        } else if (window.addEventListener) {
                            // 对于支持 addEventListener 的现代浏览器
                            document.addEventListener('DOMContentLoaded', initFn)
                            window.addEventListener('load', initFn)
                        } else if (document.attachEvent) {
                            // 检查是否为 IE8 或更早的版本
                            // 使用 IE 特有的 attachEvent 方法来监听 DOMContentLoaded 事件
                            document.attachEvent('onreadystatechange', function() {
                                if (document.readyState === 'complete') {
                                    initFn()
                                }
                            })
                            window.attachEvent('onload', initFn)
                        }

                    })()
                </script><script>
                    // js error code
                    window.onerror = function (msg, url, lineNo, columnNo, error) {
                        var createXMLHttpRequest = function () {
                            var xmlHttp
                            if(window.XMLHttpRequest){
                                xmlHttp = new XMLHttpRequest();
                            }else if(window.ActiveXObject){
                                xmlHttp = new ActiveXObject("Microsoft.XMLHTTP");
                            }
                            return xmlHttp
                        };
                        var data = 'message=' + encodeURIComponent(msg)
                            + '&filename=' + encodeURIComponent(url)
                            + '&lineno=' + lineNo
                            + '&colno=' + columnNo
                            + '&stack=' + ((error && error.stack) ? encodeURIComponent(error.stack) : '');
                        var xhr = createXMLHttpRequest();
                        if (!xhr) { return; }
                        xhr.open('POST', '/js_error', true);
                        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
                        xhr.send(data);
                    };
                </script><?php
            } );
        }
    }

    public static function save_js_error () {
        $user_agent = isset( $_SERVER['HTTP_USER_AGENT'] ) ? $_SERVER['HTTP_USER_AGENT'] : '';
        $origin = isset( $_SERVER['HTTP_ORIGIN'] ) ? $_SERVER['HTTP_ORIGIN'] : '';
        $referer = isset( $_SERVER['HTTP_REFERER'] ) ? $_SERVER['HTTP_REFERER'] : ''; // Referer

        // CORS headers
        header( 'Access-Control-Allow-Origin: ' . $origin );
        header( 'Access-Control-Allow-Headers: Content-Type' );
        header( 'Access-Control-Allow-Methods: POST' );

        if ( $origin ) $host = parse_url( $origin, PHP_URL_HOST ); // 没有端口号
        else $host = 'origin_not_set';

        $log_path = ABSPATH . 'wp-content/uploads/js_error';
        if ( ! is_dir( $log_path ) ) {
            mkdir( $log_path );
        }
        $log_path = $log_path . '/' . $host;
        if ( ! is_dir( $log_path ) ) {
            mkdir( $log_path );
        }
        $log_file = $log_path . '/' . date( 'Ymd-His' ) . '-' . rand(1000, 9999) . '.log';
        file_put_contents( $log_file, json_encode( [
            'message' => isset( $_POST['message'] ) ? $_POST['message'] : '',
            'filename' => isset( $_POST['filename'] ) ? $_POST['filename'] : '',
            'lineno' => isset( $_POST['lineno'] ) ? $_POST['lineno'] : '',
            'colno' => isset( $_POST['colno'] ) ? $_POST['colno'] : '',
            'stack' => isset( $_POST['stack'] ) ? $_POST['stack'] : '',
            'host' => $host,
            'origin' => $origin,
            'referer' => $referer,
            'user_agent' => $user_agent,
        ], JSON_PRETTY_PRINT ) );

        die;
    }

    public static function save_cf7_record () {
        $origin = isset( $_SERVER['HTTP_ORIGIN'] ) ? $_SERVER['HTTP_ORIGIN'] : '';

        // CORS headers
        header( 'Access-Control-Allow-Origin: ' . $origin );
        header( 'Access-Control-Allow-Headers: Content-Type' );
        header( 'Access-Control-Allow-Methods: POST' );

        if ( $origin ) $host = parse_url( $origin, PHP_URL_HOST ); // 没有端口号
        else $host = 'origin_not_set';

        $log_path = ABSPATH . 'wp-content/uploads/cf7_record';
        if ( ! is_dir( $log_path ) ) {
            mkdir( $log_path );
        }
        $log_path = $log_path . '/' . $host;
        if ( ! is_dir( $log_path ) ) {
            mkdir( $log_path );
        }
        $log_file = $log_path . '/' . date( 'Ymd-His' ) . '-' . rand(1000, 9999) . '.log';
        file_put_contents( $log_file, json_encode( $_POST, JSON_PRETTY_PRINT ) );

        die;
    }

    public static function show_cf7_records () {
        if ( ! is_user_logged_in() ) return;
        $type = isset( $_GET['type'] ) ? $_GET['type'] : '';
        $domain = isset( $_GET['domain'] ) ? $_GET['domain'] : '';
        $date = isset( $_GET['date'] ) ? $_GET['date'] : '';
        $base_dir = ABSPATH . 'wp-content/uploads';
        $js_dir = $base_dir . '/js_error';
        $cf7_dir = $base_dir . '/cf7_record';
        ?><!DOCTYPE html>
        <html lang="en">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>Infility Tools Error Records</title>
            <style>
                table {
                    border-collapse: collapse;
                }
                table, th, td {
                    border: 1px solid black;
                }
                th, td {
                    padding: 5px;
                    text-align: left;
                }
            </style>
        </head>
        <body><?php
        if ( $type === 'js' ) {
            $target_dir = $js_dir . '/' . $domain;
            $names = scandir( $target_dir );
            $names = array_diff( $names, [ '.', '..' ] );
            if ( $date ) {
                $names = array_filter( $names, function ( $name ) use ( $date ) {
                    return strpos( $name, $date ) !== false;
                });
            }
            ?>
            <table>
                <tr>
                    <th>Log</th>
                    <th>Message</th>
                    <th>File Name</th>
                    <th>Line</th>
                </tr>
                <?php
                foreach ($names as $name) {
                    $file = $target_dir . '/' . $name;
                    $obj = json_decode( file_get_contents( $file ), true );
                    echo '<tr>'
                        . '<td nowrap><a href="/wp-content/uploads/js_error/' . $domain . '/' . $name . '" target="_blank">' . $name . '</a></td>'
                        . '<td nowrap>' . $obj['message'] . '</td>'
                        . '<td nowrap>' . $obj['filename'] . '</td>'
                        . '<td nowrap>' . $obj['lineno'] . '</td>'
                        . '</tr>';
                }
                ?>
            </table>
            <?php
        } else if ( $type === 'cf7' ) {
            $target_dir = $cf7_dir . '/' . $domain;
            $names = scandir( $target_dir );
            $names = array_diff( $names, [ '.', '..' ] );
            if ( $date ) {
                $names = array_filter( $names, function ( $name ) use ( $date ) {
                    return strpos( $name, $date ) !== false;
                });
            }
            ?>
            <table>
                <tr>
                    <th>Log</th>
                    <th>your-name</th>
                    <th>your-email</th>
                    <th>your-phone</th>
                    <th>your-message</th>
                </tr>
                <?php
                foreach ($names as $name) {
                    $file = $target_dir . '/' . $name;
                    $obj = json_decode( file_get_contents( $file ), true );
                    echo '<tr>'
                        . '<td nowrap><a href="/wp-content/uploads/cf7_record/' . $domain . '/' . $name . '" target="_blank">' . $name . '</a></td>'
                        . '<td nowrap>' . $obj['your-name'] . '</td>'
                        . '<td nowrap>' . $obj['your-email'] . '</td>'
                        . '<td nowrap>' . $obj['your-phone'] . '</td>'
                        . '<td nowrap>' . $obj['your-message'] . '</td>'
                        . '</tr>';
                }
                ?>
            </table>
            <?php
        } else {
            // get all names under the directory
            $js_names = scandir( $js_dir );
            $js_names = array_diff( $js_names, [ '.', '..' ] );
            $js_names = array_values( $js_names );

            echo '<div>JS</div>';
            foreach ($js_names as $i => $name) {
                echo '<a href="/cf7_records?type=js&domain=' . $name . '&date=' . date('Ymd') . '" target="_blank">' . $name . '</a> &nbsp; '
                    . '<a href="/cf7_records?type=js&domain=' . $name . '&date=' . date('Ymd', strtotime( '-1 day' )) . '" target="_blank">' . date('Ymd', strtotime( '-1 day' )) . '</a>'
                    . '<br/>';
            }

            $cf7_names = scandir( $cf7_dir );
            $cf7_names = array_diff( $cf7_names, [ '.', '..' ] );
            $cf7_names = array_values( $cf7_names );

            echo '<div>CF7</div>';
            foreach ($cf7_names as $i => $name) {
                echo '<a href="/cf7_records?type=cf7&domain=' . $name . '&date=' . date('Ymd') . '" target="_blank">' . $name . '</a> &nbsp; '
                    . '<a href="/cf7_records?type=cf7&domain=' . $name . '&date=' . date('Ymd', strtotime( '-1 day' )) . '" target="_blank">' . date('Ymd', strtotime( '-1 day' )) . '</a>'
                    . '<br/>';
            }
        }
        echo '</body></html>';
        die;
    }
}
InfilityGlobalErrorRecord::init();
