<?php
/*↓
Plugin Name: Infility Global
Plugin URI: https://www.infility.cn/
Description: Infility公共插件
Version: 1.9.0
Author: Infility CJJ
Author URI: https://www.infility.cn/
License: GPLv2
Requires at least: 5.6
Tested up to: 6.4.3
Requires PHP: 7.0

v1.6.0 (20231017) Step: keyword pages.
V1.8.0 (20240306) Step: Consent mode.
V1.8.1 (20240306) Step: Update consent mode.
V1.9.0 (20240318) Step: JS error records and CF7 records.
*/

class infility_global_plugins_class{
	function __construct()
	{
		define( 'INFILITY_GLOBAL_VERSION', '1.9.0');
		define( 'INFILITY_GLOBAL_PATH', plugin_dir_path( __FILE__ ) ); // fullpath/wp-content/plugins/infility-global/ // 有斜杠
		define( 'INFILITY_GLOBAL_URL', plugins_url( '/', __FILE__ ) ); // https://the_domain/wp-content/plugins/infility-global/ // 斜杠是自己加的
		define( 'INFILITY_GLOBAL_OPTION_KEY', 'infility_global_configure' );

		register_activation_hook( __FILE__, array($this,'IGP_activate') );
		spl_autoload_register('self::class_auto_load'); //5.1.2

		// 为避免询盘遗漏，这个功能当前来说是默认启用的。
		// 只是判断了 request method 以及 request uri ，不符合条件的会直接跳过，对性能影响不大。
		// 以后可以改成 widget ，控制是否开启。
		require( INFILITY_GLOBAL_PATH . 'include/InfilityGlobalErrorRecord.php' );

		add_action( 'init', array( $this, 'api_login_check' ) );
		add_action( 'init', array( $this, 'api_action' ) );
		add_action( 'init', array( $this, 'IGP_load_textdomain' ) );
		add_action('admin_menu',array($this,'IGP_create_menu'));

		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

		if($iconUrl = get_option('infility_advance_iconfont')){
			wp_enqueue_style('infility_advance_icon',$iconUrl);
		}

		add_shortcode( 'infility_power_by', array( $this, 'infility_power_by_html' ) );


		$optionAry = get_option(INFILITY_GLOBAL_OPTION_KEY);
		foreach ($optionAry['plugins'] as $k => $v) {
			if ($v==1) {
				$key = $this->infility_global_get_plugins_config($k,'key');
				require_once( __DIR__ . "/widgets/{$key}/{$key}.php" );
			}
		}


		add_filter( 'mime_types', array($this,'wpse_mime_types') );

		$this->clean_revision();
	}

	public function enqueue_scripts () {
		wp_enqueue_script('jquery');
		wp_enqueue_script( 'IGP_global', plugins_url( 'js/global.js', __FILE__ ), ['jquery'], INFILITY_GLOBAL_VERSION, true );
		// wp_enqueue_script('IGP_js',plugins_url('js/contact_form_plugins.js',__FILE__),['jquery'],false,true);
		wp_enqueue_style('IGP_css',plugins_url('css/infility_global.css',__FILE__),false, INFILITY_GLOBAL_VERSION, 'all');
	}


	private static function class_auto_load($class_name)
    {
		$file = __DIR__ . '/include/class/' . $class_name . '.class.php';
		@is_file($file) && include($file);
	}

	function IGP_activate() {
		global $wpdb;

		$pluginsAry = array(
			'plugins'	=>	array(
				'CFP'		=>	0,
				'ETab'		=>	0,
				'301jump'	=>	0,
				'PowerBy'	=>	0,
			)
		);
		update_option(INFILITY_GLOBAL_OPTION_KEY,$pluginsAry);
	}

	function infility_global_get_plugins_config($key,$type='title') {
		global $wpdb;

		$pluginsAry = array(
			'CFP'	=>	array(//键值一定要用大坨峰  不能用|   因为构成链接的时候要|分割
				'key'		=>	'contact-form-plugins',
				'title'		=>	'Contact Form 7增强插件',
				'brief'		=>	'Contact Form 7增强插件,可定义表单元素宽度,设置提交后重定向链接',
				'href'		=>	'CFP_setting_page',
				'file'		=>	'widgets/contact-form-plugins/contact-form-plugins.php',
				'class'		=>	'contact_form_plugins_class',
			),
			// 'ETab'	=>	array(
			// 	'key'		=>	'elementor-tab',
			// 	'title'		=>	'Infility Tabs插件',
			// 	'brief'		=>	'根据Advanced Tabs插件研发改进的选项卡插件,新增响应式适配,切换效果等',
			// ),
			'ETab'	=>	array(
				'key'		=>	'elementor-tab',
				'title'		=>	'Elementor 组件优化',
				'brief'		=>	'优化Elementor里面的组件,更符合设计师使用',
			),
			'301jump'	=>	array(
				'key'		=>	'infility-redirect',
				'title'		=>	'Infility 重定向工具',
				'brief'		=>	'1.可增加网站重定向链接.<br />2.根据文档提供的链接,检测是否为死链,然后添加到301重定向队列',
				'href'		=>	'redirect_setting_page',
				'file'		=>	'widgets/infility-redirect/infility-redirect.php',
				'class'		=>	'infility_redirect_class',
			),
			'PowerBy'	=>	array(
				'key'		=>	'powey-by',
				'title'		=>	'Infility Power By',
				'brief'		=>	'[infility_power_by] 短码自动生成PowerBy 连接到Infility官网',
				'swtich'	=>	0,
			),
            'ChatTool'	=>	array(
                'key'		=>	'infility-chat-tool',
                'title'		=>	'Infility Chat Tool',
                'brief'		=>	'自动生成聊天工具',
                'href'		=>	'chat_tool_setting_page',
                'file'      =>  'widgets/infility-chat-tool/infility-chat-tool.php',
                'class'     =>  'infility_chat_tool',
            ),
            'KeywordPages'	=>	array(
                'key'		=>	'keyword-pages',
                'title'		=>	'Keyword Pages',
                'brief'		=>	'根据关键词自动生成页面',
                'href'		=>	'keyword_pages_setting_page',
                'file'      =>  'widgets/keyword-pages/keyword-pages.php',
                'class'     =>  'keyword_pages',
            ),
            'ConsentMode'	=>	array(
                'key'		=>	'consent-mode',
                'title'		=>	'Consent Mode',
                'brief'		=>	'意见征求模式',
                'href'		=>	'keyword_pages_setting_page',
                'file'		=>	'widgets/consent-mode/consent-mode.php',
                'class'		=>	'keyword_pages',
            ),
		);

		$return = isset( $pluginsAry[$key][$type] ) ? $pluginsAry[$key][$type] : '';
		if ($type=='href') {
			$return = $pluginsAry[$key]['title'];
			if (isset($pluginsAry[$key]['href'])) {
				$current_url = home_url(remove_query_arg(array('set_type')));
				$set_type = $key.'|'.$pluginsAry[$key]['href'];
				$return = "<a href='{$current_url}&set_type={$set_type}'>{$return}</a>";
			}
		}else if($type=='swtich'){
			if (!isset($pluginsAry[$key][$type])) {
				$return = 1;
			}
		}

		$optionAry = get_option(INFILITY_GLOBAL_OPTION_KEY);
		$IsUpdate = false;
		foreach ($pluginsAry as $k => $v) {
			if (!isset($optionAry['plugins'][$k])) {
				$IsUpdate = true;
				$optionAry['plugins'][$k] = 0;
			}
		}

		if ($IsUpdate) {
			update_option(INFILITY_GLOBAL_OPTION_KEY,$optionAry);
		}

		return $return;
	}

	function IGP_ajax_load(){
		// wp_localize_script('TF_js','ajax_object',array('ajax_url'=>	admin_url('admin-ajax.php')));
	}

	function IGP_load_textdomain() {

		//加载 languages 目录下的翻译文件 zh_CN
		$currentLocale = get_locale();

		if( !empty( $currentLocale ) ) {

			$moFile = dirname(__FILE__) . "/languages/{$currentLocale}.mo";

			if( @file_exists( $moFile ) && is_readable( $moFile ) ) load_textdomain( 'infility-global', $moFile );
		}
	}

	function IGP_create_menu(){
		add_menu_page(
			__('Public Settings','infility-global'),
			__('Public Settings','infility-global'),
			'manage_options',
			'infility_global_plugins',
			array($this,'IGP_nav_page'),
			plugins_url('images/wp-icon.png',__FILE__)
		);
	}

	function IGP_nav_page(){
		if ( isset( $_GET['set_type'] ) && $_GET['set_type']) {
			$set_type = $_GET['set_type'];
			$setTypeAry = explode('|', $set_type);
			$className = $this->infility_global_get_plugins_config($setTypeAry[0],'class');

			if (!class_exists($className)) {
				$file = $this->infility_global_get_plugins_config($setTypeAry[0],'file');
				include($file);
			}
			$NewClass = new $className;
			$NewClass->{$setTypeAry[1]}();
		} else if ( isset( $_GET['GuidePage'] ) && $_GET['GuidePage'] ){
			$GuidePage = $_GET['GuidePage'];
			$this->IGP_guide_page($GuidePage);
		} else {
			$this->IGP_setting_page();
		}
	}

	function IGP_setting_page(){
		global $wpdb;

		if (!empty($_POST) && check_admin_referer('IGP_nonce')) {
			@extract($_POST, EXTR_PREFIX_ALL, 'p');


			$optionAry = get_option(INFILITY_GLOBAL_OPTION_KEY);

			foreach ($optionAry['plugins'] as $k => $v) {
				$optionAry['plugins'][$k] = (int)${"p_{$k}_swtich"};
				// Notice: Undefined variable: p_PowerBy_swtich in D:\Programs\phpEnv\www\global.local.com\wp-content\plugins\infility-global\infility_global.php on line 213
			}

			update_option(INFILITY_GLOBAL_OPTION_KEY,$optionAry);

			echo ('<div id="message" class="updated"><p><strong>'.__('Settings saved success!','infility-global').'</strong></p></div>');
		}

		$optionAry = get_option(INFILITY_GLOBAL_OPTION_KEY);
		$i = 0;

		include('include/infility_setting_page.php');
	}

	function IGP_guide_page($type){
		$name = $this->infility_global_get_plugins_config($type,'title');

		$mainUrl = home_url(remove_query_arg(array('set_type','GuidePage')));
		include('include/infility_guide_page.php');
	}

	function infility_power_by_html() {
		global $wpdb;

	    action::check_power_by_html('');
	    $poweyByData = get_option('infility_power_by');

	    ob_start();
?>
			<div id="powey_by" class='<?=$poweyByData['IsHide']==1?'hide':'';?>'><?=htmlspecialchars_decode($poweyByData['PowerBy'])?></div>
<?php
	    $html = $poweyByData['IsDel']==1?'':ob_get_contents();
	    ob_end_clean();

	    return $html;
	}

	function clean_revision() {
		global $wpdb;

		$time = strtotime(date('Y-m-d',time()));
	    $cleanTimeData = get_option('clean_revision');
	    if (!$cleanTimeData) {
	    	$cleanTime = strtotime(date('Y-m-d',time()));
	    	$data = array(
	    		'time'		=>	$cleanTime,
	    		'IsClean'	=>	0,
	    	);
	    	update_option('clean_revision',$data);
	    	$cleanTimeData = get_option('clean_revision');
	    }
	    $cleanTime = strtotime(date('Y-m-d',$cleanTimeData['time']));

	    if (!$cleanTimeData['IsClean'] || ($time-$cleanTime)>(86400 * 7)) {
	    	$wpdb->delete('wp_posts',array('post_type'=>'revision'));

	    	$cleanTime = strtotime(date('Y-m-d',time()));
	    	$data = array(
	    		'time'		=>	$cleanTime,
	    		'IsClean'	=>	1,
	    	);

	    	update_option('clean_revision',$data);
	    }
	}

	function wpse_mime_types( $existing_mimes ) {
	    // Add csv to the list of allowed mime types
	    $existing_mimes['svg'] = 'image/svg';

	    return $existing_mimes;
	}

	function api_login_check() {
		if ( ! isset( $_GET['LOGIN_TYPE'] )
			|| ! $_GET['LOGIN_TYPE']
			|| $_GET['LOGIN_TYPE']!='infility_oa'
		) return true;

		$token = $_GET['login_token'];
		$data = [
			'TOKEN_TYPE'	=>	$_GET['LOGIN_TYPE'],
			'TOKEN'			=>	$token
		];
		$response = str::curl('https://os.infility.cn/',$data);
		$result = str::json_data($response,'decode');
		if ($result['ret']==1) {

			$email = $result['msg']['email'];
			$user = get_user_by( 'email', $email );

			if( $user ) {
			    wp_set_current_user( $user->id, $user->user_login );
			    wp_set_auth_cookie( $user->id );
			    do_action( 'wp_login', $user->user_login, $user );

			    wp_redirect("/wp-admin/");
			    exit;
			}
		}

	    return true;
	}

	function api_action() {
		if ( ! isset( $_GET['ACTION_TYPE'] )
			|| ! $_GET['ACTION_TYPE']
			|| $_GET['ACTION_TYPE']!='infility_oa'
		) return true;

		$ACTION_DATA = str::json_data(base64_decode($_GET['i']),'decode');
		@extract($ACTION_DATA, EXTR_PREFIX_ALL, 'g');
		@extract($_POST, EXTR_PREFIX_ALL, 'p');

		$time = $g_time;
		if ($g_INFILITY_APIKEY == str::api_key($time)) {
			if ($p_do_action=='edit_power_by_html') {
				action::check_power_by_html($_POST);
			}else{
				if (method_exists('action', $p_do_action)) {
					$postData = $_POST;
					eval("action::{$p_do_action}(\$postData);");
					exit;
				}
			}
		}


	    return str::e_json('',1);
	}
}
new infility_global_plugins_class();


